#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
from taz.dls import Datalake
import sys
import tests.config as cfg


class DatalakeTests(unittest.TestCase):

    def setUp(self):

        self.path = cfg.dls["path"]
        self.file_name = cfg.dls["file_name"]
        self.gz_file_name = cfg.dls["gz_file_name"]
        self.tmp_file_name = cfg.dls["tmp_file_name"]
        self.datalake = Datalake(
            cfg.dls["dls_name"],
            cfg.dls["tenant_id"],
            cfg.dls["client_id"],
            cfg.dls["client_secret"],
            proxy=cfg.dls["https_proxy"])

    def test_010_exists(self):
        self.assertTrue(self.datalake is not None)

    def test_020_df(self):
        stats = self.datalake.df(self.path)
        print("stats", stats)
        self.assertTrue(stats is not None)

    def test_030_ls(self):
        list_files = self.datalake.ls(self.path)
        print(list_files[0])
        self.assertTrue(list_files)

    def test_035_open(self):
        fd = self.datalake.open(self.path + '/' + self.file_name)
        fd.readline()
        fd.close()

    def test_040_copy(self):
        self.datalake.get(self.path + '/' + self.file_name, self.tmp_file_name)

    def test_050_read_csv(self):
        df = self.datalake.read_csv(
            self.path + '/' + self.file_name)
        self.assertTrue(df is not None)

    def test_050_read_gz_csv(self):
        df = self.datalake.read_csv(
            self.gz_file_name,
            compression="gzip")
        self.assertTrue(df is not None)


if __name__ == '__main__':
    sys.argv.append('-v')
    unittest.main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
from taz.dls import Datalake
from tests.config import *


class DatalakeTests(unittest.TestCase):

    def setUp(self):
        self.template_file = "config_template.py"
        self.dicts = [ "keyvault", "auth", "blob", "acr", "aci", "dls" ]

    def test_010_mktemplate(self):
        self.fd = open(self.template_file, "w")
        for dict in self.dicts:
            self.fd.write(f"{dict} = " + "{\n")
            for key in globals()[dict]:
                self.fd.write(f"    \"{key}\": \"xxxxxxxxx\"\n")
            self.fd.write("}\n")
        self.fd.close()

if __name__ == '__main__':
    sys.argv.append('-v')
    unittest.main()



keyvault = {
    "name": "xxxxxxxxx"
    "secret_name": "xxxxxxxxx"
    "tenant_id": "xxxxxxxxx"
    "client_id": "xxxxxxxxx"
    "client_secret": "xxxxxxxxx"
}
auth = {
    "resource_group": "xxxxxxxxx"
    "managed_identity": "xxxxxxxxx"
    "subscription_id": "xxxxxxxxx"
    "tenant_id": "xxxxxxxxx"
    "client_id": "xxxxxxxxx"
    "client_secret": "xxxxxxxxx"
}
blob = {
    "storage_account_name": "xxxxxxxxx"
    "storage_key": "xxxxxxxxx"
    "sas_key": "xxxxxxxxx"
    "container_name": "xxxxxxxxx"
    "path": "xxxxxxxxx"
    "data": "xxxxxxxxx"
}
acr = {
    "resource_group": "xxxxxxxxx"
    "registry_name": "xxxxxxxxx"
    "subscription_id": "xxxxxxxxx"
    "image_name": "xxxxxxxxx"
}
aci = {
    "resource_group": "xxxxxxxxx"
    "container_group_name": "xxxxxxxxx"
    "location": "xxxxxxxxx"
    "subscription_id": "xxxxxxxxx"
}
dls = {
    "dls_name": "xxxxxxxxx"
    "tenant_id": "xxxxxxxxx"
    "client_id": "xxxxxxxxx"
    "client_secret": "xxxxxxxxx"
    "https_proxy": "xxxxxxxxx"
    "path": "xxxxxxxxx"
    "glob_path": "xxxxxxxxx"
    "file_name": "xxxxxxxxx"
    "gz_file_name": "xxxxxxxxx"
    "tmp_file_name": "xxxxxxxxx"
}



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
from taz.blob import StorageAccount, Blob, Container
import tests.config as cfg
import sys


class BlobTests(unittest.TestCase):

    def setUp(self):
        self.storage_account_name = cfg.blob["storage_account_name"]
        self.storage_key = cfg.blob["storage_key"]
        self.sas_key = cfg.blob["sas_key"]
        self.container_name = cfg.blob["container_name"]
        self.path = cfg.blob["path"]
        self.gzip_path = cfg.blob["gzip_path"]
        self.data = cfg.blob["data"]

    def test_010_get_storage_account(self):
        self.storage_account = StorageAccount(
            self.storage_account_name,
            self.storage_key)
        self.assertTrue(self.storage_account is not None)

    def test_012_get_container(self):
        self.test_010_get_storage_account()
        self.container = Container(self.storage_account, self.container_name)

    def test_015_create_container(self):
        self.test_012_get_container()
        self.container.create()

    def test_020_list_containers(self):
        self.test_010_get_storage_account()
        self.containers = self.storage_account.list_containers()
        for container in self.containers:
            print(container)
        self.assertTrue(self.containers is not None)

    def test_030_list_blobs(self):
        self.test_010_get_storage_account()
        self.blobs = self.storage_account.list_blobs(self.container_name)
        self.assertTrue(self.blobs is not None)

    def test_040_get_blob(self):
        self.test_010_get_storage_account()
        self.blob = Blob(
            self.storage_account,
            self.container_name,
            self.path,
            self.sas_key)
        self.assertTrue(self.blob is not None)

    def test_042_get_gzip_blob(self):
        self.test_010_get_storage_account()
        self.gzip_blob = Blob(
            self.storage_account,
            self.container_name,
            self.gzip_path,
            self.sas_key)
        self.assertTrue(self.gzip_blob is not None)

    def test_045_blob_write(self):
        self.test_040_get_blob()
        self.blob.write(self.path, bytes(self.data, 'utf-8'))

    def test_047_blob_gzip_write(self):
        self.test_042_get_gzip_blob()
        self.gzip_blob.gzip_write(self.gzip_path, bytes(self.data, 'utf-8'))

    def test_050_get_blob_sas_token(self):
        self.test_040_get_blob()
        self.sas_token = self.blob.get_sas_token()
        self.assertTrue(self.sas_token is not None)

    def test_060_get_blob_url(self):
        self.test_040_get_blob()
        self.url = self.blob.get_url()
        self.assertTrue(self.url is not None)

    def test_070_blob_read_raw(self):
        self.test_040_get_blob()
        self.assertTrue(self.blob.read() is not None)

    def test_080_blob_read_csv(self):
        self.test_040_get_blob()
        self.csv_datas = self.blob.read_csv()
        print(self.csv_datas)
        self.assertTrue(self.csv_datas is not None)

    def test_090_blob_read_gzip_csv(self):
        self.test_042_get_gzip_blob()
        self.csv_datas = self.gzip_blob.read_csv(compression="gzip")
        print(self.csv_datas)
        self.assertTrue(self.csv_datas is not None)

    def test_100_blob_delete(self):
        self.test_040_get_blob()
        self.blob.delete()

    def test_110_gzip_blob_delete(self):
        self.test_042_get_gzip_blob()
        self.gzip_blob.delete()

    def test_120_container_delete(self):
        self.test_012_get_container()
        self.container.delete()


if __name__ == '__main__':
    sys.argv.append('-v')
    unittest.main()
